@@ -80,15 +80,22 @@ def test_pypi_project_changed(replica_xom):
     handler = PypiProjectChanged(replica_xom)
     class Ev:
         value = dict(projectname="newproject", serial=12)
-        typedkey = replica_xom.keyfs.get_key("PYPILINKS")
+        typedkey = replica_xom.keyfs.get_key("PYPILINKS")(name="newproject")
     handler(Ev())
     assert replica_xom.pypimirror.name2serials["newproject"] == 12
     class Ev2:
         value = dict(projectname="newproject", serial=15)
-        typedkey = replica_xom.keyfs.get_key("PYPILINKS")
+        typedkey = replica_xom.keyfs.get_key("PYPILINKS")(name="newproject")
     handler(Ev2())
     assert replica_xom.pypimirror.name2serials["newproject"] == 15
 
+    class Ev3:
+        typedkey = replica_xom.keyfs.get_key("PYPILINKS")(name="newproject")
+        value = None
+    handler(Ev3())
+    assert "newproject" not in replica_xom.pypimirror.name2serials
+
+
 class TestReplicaThread:
     @pytest.fixture
     def rt(self, makexom):
@@ -152,6 +159,17 @@ class TestTweenReplica:
         assert response.headers.get("X-DEVPI-SERIAL") == "10"
         assert l == [10]
 
+    def test_preserve_reason(self, makexom, blank_request, reqmock, monkeypatch):
+        xom = makexom(["--master", "http://localhost"])
+        reqmock.mock("http://localhost/blankpath",
+                     code=200, reason="GOOD", headers={"X-DEVPI-SERIAL": "10"})
+        l = []
+        monkeypatch.setattr(xom.keyfs.notifier, "wait_tx_serial",
+                            lambda x: l.append(x))
+        handler = tween_replica_proxy(None, {"xom": xom})
+        response = handler(blank_request(method="PUT"))
+        assert response.status == "200 GOOD"
+
     def test_write_proxies_redirect(self, makexom, blank_request, reqmock, monkeypatch):
         xom = makexom(["--master", "http://localhost",
                        "--outside-url=http://my.domain"])
